==> ejc-technologymanage-impl-3.0.0-20220425.074720-12-sources.jar: com/ejianc/business/constructor/bean/FazdEntity.java <==
package com.ejianc.business.constructor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 方案字典实体
 * 
 * @author generator
 * 
 */
 @TableName("t_technologymanage_fazd")
public class FazdEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="qbm")
    private Integer qbm; // 全编码
    @TableField(value="mc")
    private String mc; // 名称
    @TableField(value="fasm")
    private String fasm; // 方案说明
    @TableField(value="bcbm")
    private Integer bcbm; // 本层编码
    @TableField(value="pid")
    private Long pid; // 上级编码
    @TableField(value="child_flag")
    private Integer childFlag; // 子级标志(0:否 1：是)
    @TableField(value="status")
    private Integer status; // 字典启用状态
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Integer getQbm() {
        return qbm;
    }

    public void setQbm(Integer qbm) {
        this.qbm = qbm;
    }
    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }
    public String getFasm() {
        return fasm;
    }

    public void setFasm(String fasm) {
        this.fasm = fasm;
    }
    public Integer getBcbm() {
        return bcbm;
    }

    public void setBcbm(Integer bcbm) {
        this.bcbm = bcbm;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getChildFlag() {
        return childFlag;
    }

    public void setChildFlag(Integer childFlag) {
        this.childFlag = childFlag;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}

==> ejc-technologymanage-impl-3.0.0-20251107.012240-56-sources.jar: com/ejianc/business/constructor/bean/FazdEntity.java <==
package com.ejianc.business.constructor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 方案字典实体
 * 
 * @author generator
 * 
 */
 @TableName("t_technologymanage_fazd")
public class FazdEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="qbm")
    private Integer qbm; // 全编码
    @TableField(value="mc")
    private String mc; // 名称
    @TableField(value="fasm")
    private String fasm; // 方案说明
    @TableField(value="bcbm")
    private Integer bcbm; // 本层编码
    @TableField(value="pid")
    private Long pid; // 上级编码
    @TableField(value="child_flag")
    private Integer childFlag; // 子级标志(0:否 1：是)
    @TableField(value="status")
    private Integer status; // 字典启用状态
    @TableField(value = "pname")
    private String pname;//上级名称
    @TableField(value="level_type")
    private String levelType; // 安全级别
    @TableField(value="seal_type")
    private String sealType; // 用印规范

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Integer getQbm() {
        return qbm;
    }

    public void setQbm(Integer qbm) {
        this.qbm = qbm;
    }
    public String getMc() {
        return mc;
    }

    public void setMc(String mc) {
        this.mc = mc;
    }
    public String getFasm() {
        return fasm;
    }

    public void setFasm(String fasm) {
        this.fasm = fasm;
    }
    public Integer getBcbm() {
        return bcbm;
    }

    public void setBcbm(Integer bcbm) {
        this.bcbm = bcbm;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }

    public Integer getChildFlag() {
        return childFlag;
    }

    public void setChildFlag(Integer childFlag) {
        this.childFlag = childFlag;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }

    public String getPname() {
        return pname;
    }

    public void setPname(String pname) {
        this.pname = pname;
    }

    public String getLevelType() {
        return levelType;
    }

    public void setLevelType(String levelType) {
        this.levelType = levelType;
    }

    public String getSealType() {
        return sealType;
    }

    public void setSealType(String sealType) {
        this.sealType = sealType;
    }
}
